# pyourls3

[![Build Status](https://travis-ci.com/codemicro/pyourls3.svg?branch=master)](https://travis-ci.com/codemicro/pyourls3)
[![Mozilla Public Licence v2](https://img.shields.io/badge/Licence-MPL--2.0-yellow.svg)](https://www.mozilla.org/en-US/MPL/)
[![Written for Python 3.7](https://img.shields.io/badge/Written%20for-Python%20<=%203.5-green.svg?logo=python&logoColor=white)](https://www.python.org)

A Python 3 API wrapper for [YOURLS](https://yourls.org/) - Pyourls3 is an API wrapper module written specifically for Python 3, to work with the YOURLS link shortener. It's
designed to supersede the old [`python-yourls`](https://www.github.com/tflink/python-yourls) written by [tflink](https://github.com/tflink),
built using the fantastic [`requests`](https://pypi.org/project/requests/) library.

Documentation can be found at https://www.tdpain.net/projects/pyourls3.

The PyPI page can be found at https://pypi.org/project/pyourls3

## Contibuting
This is an open source project, so feel free to make some changes or fix something, and submit a pull request. See the
contributing page in the docs at https://www.tdpain.net/projects/pyourls3/contributing.html.
